@@ -2,4 +2,4 @@ from dbutils_typehint.fs import FS
 
 
 class DBUtils:
-    fs = None  # type: FS
+    fs = FS()
